pub struct FunctionSummary {
pub blocks_count: usize,
pub blocks_executed: usize,
pub entry_count: u64,
pub exit_count: u64,
pub branches_count: usize,
pub branches_executed: usize,
pub branches_taken: usize,
}Expand description
Statistical summary of a function.
Fields
blocks_count: usizeNumber of basic blocks in the function (excluding the enter- and exit-blocks).
blocks_executed: usizeNumber of basic blocks that has been executed (having non-zero count).
entry_count: u64How many times the function is called.
exit_count: u64How many times the function has returned.
branches_count: usizeNumber of conditional branches in the function.
branches_executed: usizeNumber of conditional basic blocks that has been executed.
branches_taken: usizeNumber of branches that has been taken.